# Generated by roxygen2: do not edit by hand

export(clean_variable_names)
export(infer_data_types)
export(normalize_units)
export(read_messy_panel)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(stringr,str_extract)
importFrom(stringr,str_remove)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_squish)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_trim)
